:mod:`ginsfsm.protocols.wsgi`
=============================

.. automodule:: ginsfsm.protocols.wsgi

Gojs involved:

.. image:: wsgi-server.png

.. automodule:: ginsfsm.protocols.wsgi.server.c_wsgi_server
